@@ -695,15 +695,28 @@ class PSD:
                 xlim = [np.min(xlim), np.max(xlim)]
 
         if transpose:
+            ylim = [np.min(x_axis), np.max(x_axis)]
+            xlim = [np.min(y_axis), np.max(y_axis)]
             x_axis, y_axis = y_axis, x_axis
-            xlim, ylim = ylim, xlim
+            ax.plot(x_axis,y_axis, **plot_kwargs)
+
             xticks, yticks = yticks, xticks
             xlabel, ylabel = ylabel, xlabel
-            ax.set_ylim(ylim[::-1])
         else:
             ax.set_xlim(xlim)
+            ax.plot(x_axis, y_axis, **plot_kwargs)
 
-        ax.plot(x_axis, y_axis, **plot_kwargs)
+        #
+        # if transpose:
+        #     x_axis, y_axis = y_axis, x_axis
+        #     xlim, ylim = ylim, xlim
+        #     xticks, yticks = yticks, xticks
+        #     xlabel, ylabel = ylabel, xlabel
+        #     ax.set_ylim(ylim[::-1])
+        #     # print('thing',ylim[::-1])
+        # else:
+        #     ax.set_xlim(xlim)
+        # ax.plot(x_axis, y_axis, **plot_kwargs)
 
 
         # plot significance levels
@@ -936,7 +949,7 @@ class MultiplePSD:
         return new
 
 
-    def plot(self, figsize=[10, 4], in_loglog=True, in_period=True, xlabel=None, ylabel='Amplitude', title=None,
+    def plot(self, figsize=[10, 4], in_loglog=True, in_period=True, xlabel=None, ylabel='PSD', title=None,
              xlim=None, ylim=None, savefig_settings=None, ax=None, xticks=None, yticks=None, legend=True,
              colors=None, cmap=None, norm=None, plot_kwargs=None, lgd_kwargs=None):
         '''Plot multiple PSDs on the same plot
@@ -1106,7 +1119,7 @@ class MultiplePSD:
             return ax
 
     def plot_envelope(self, figsize=[10, 4], qs=[0.025, 0.5, 0.975],
-             in_loglog=True, in_period=True, xlabel=None, ylabel='Amplitude', title=None,
+             in_loglog=True, in_period=True, xlabel=None, ylabel='PSD', title=None,
              xlim=None, ylim=None, savefig_settings=None, ax=None, xticks=None, yticks=None, plot_legend=True,
              curve_clr=sns.xkcd_rgb['pale red'], curve_lw=3, shade_clr=sns.xkcd_rgb['pale red'], shade_alpha=0.3, shade_label=None,
              lgd_kwargs=None, members_plot_num=10, members_alpha=0.3, members_lw=1, seed=None):
