@@ -1,13 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """
-Created on Tue Feb 25 05:46:36 2020
-
-@author: deborahkhider
-
-Contains all relevant mapping functions
+Mapping utilities for geolocated objects, leveraging Cartopy.
 """
-__all__=['map_all']
+__all__=['map', 'compute_dist']
 
 import cartopy.crs as ccrs
 import cartopy.feature as cfeature
@@ -15,7 +11,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 
-from .plotting import savefig, showfig 
+from .plotting import savefig
 
 def set_proj(projection='Robinson', proj_default = True): 
     """ Set the projection for Cartopy.
@@ -33,7 +29,7 @@ def set_proj(projection='Robinson', proj_default = True):
         'Geostationary','NearsidePerspective','EckertI','EckertII',
         'EckertIII','EckertIV','EckertV','EckertVI','EqualEarth','Gnomonic',
         'LambertAzimuthalEqualArea','NorthPolarStereo','OSNI','SouthPolarStereo'
-    proj_default : bool
+    proj_default : bool; {True,False}
         If True, uses the standard projection attributes from Cartopy.
         Enter new attributes in a dictionary to change them. Lists of attributes
         can be found in the Cartopy documentation: 
@@ -45,7 +41,7 @@ def set_proj(projection='Robinson', proj_default = True):
         
     See Also
     --------
-    pyleoclim.utils.mapping.map_all : mapping function making use of the projection
+    pyleoclim.utils.mapping.map : mapping function making use of the projection
     
     """
     if proj_default is not True and type(proj_default) is not dict:
@@ -189,7 +185,7 @@ def set_proj(projection='Robinson', proj_default = True):
         if proj_default is True:
             proj = ccrs.OSNI() 
         else: proj = ccrs.OSNI(**proj_default)
-    elif projection == 'OSNI':
+    elif projection == 'SouthPolarStereo':
         if proj_default is True:
             proj = ccrs.SouthPolarStereo() 
         else: proj = ccrs.SouthPolarStereo(**proj_default)
@@ -198,11 +194,11 @@ def set_proj(projection='Robinson', proj_default = True):
     
     return proj
 
-def map_all(lat, lon, criteria, marker=None, color =None,
+def map(lat, lon, criteria, marker=None, color =None,
             projection = 'Robinson', proj_default = True,
            background = True,borders = False, rivers = False, lakes = False,
            figsize = None, ax = None, scatter_kwargs=None, legend=True,
-           lgd_kwargs=None,savefig_settings=None, mute=False):
+           lgd_kwargs=None,savefig_settings=None):
     """ Map the location of all lat/lon according to some criteria
     
     Map the location of all lat/lon according to some criteria. Based on functions defined in the Cartopy package. 
@@ -279,10 +275,6 @@ def map_all(lat, lon, criteria, marker=None, color =None,
           with or without a suffix; if the suffix is not given in "path", it will follow "format"
         - "format" can be one of {"pdf", "eps", "png", "ps"}
     
-    mute : bool
-        if True, the plot will not show;
-        recommend to set to true when more modifications are going to be made on ax
-    
     Returns
     -------
     
@@ -394,9 +386,6 @@ def map_all(lat, lon, criteria, marker=None, color =None,
     if 'fig' in locals():
         if 'path' in savefig_settings:
             savefig(fig, settings=savefig_settings)
-        else:
-            if not mute:
-                showfig(fig)
         return fig, ax
     else:
         return ax
